Skip site navigation (1)Skip section navigation (2)
Date:      Tue, 2 Apr 2002 04:53:31 -0800
From:      Murray Stokely <murray@FreeBSD.org>
To:        maf@splintered.net, freebsd-bugs@FreeBSD.org
Subject:   Re: conf/36606: Adding packages with sysinstall failes after
Message-ID:  <20020402125331.GC27913@freebsdmall.com>
In-Reply-To: <200204021229.g32CTwp79296@freefall.freebsd.org>
References:  <200204021229.g32CTwp79296@freefall.freebsd.org>

next in thread | previous in thread | raw e-mail | index | archive | help

--EVF5PPMfhYS0aIcm
Content-Type: text/plain; charset=us-ascii
Content-Disposition: inline
Content-Transfer-Encoding: quoted-printable

  Attached is a patch against -STABLE.  Can you please confirm that
this solves the problems you are experiencing?  The has already been
applied to -CURRENT.

Index: perform.c
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
RCS file: /a/ncvs/src/usr.sbin/pkg_install/add/perform.c,v
retrieving revision 1.57.2.8
diff -u -r1.57.2.8 perform.c
--- perform.c	23 Oct 2001 09:16:03 -0000	1.57.2.8
+++ perform.c	2 Apr 2002 11:51:13 -0000
@@ -189,7 +189,7 @@
 	     * compress an average of 75%, so multiply by 4 for good measure.
 	     */
=20
-	    if (!inPlace && min_free(playpen) < sb.st_size * 4) {
+	    if (!extract && !inPlace && min_free(playpen) < sb.st_size * 4) {
 		warnx("projected size of %qd exceeds available free space.\n"
 "Please set your PKG_TMPDIR variable to point to a location with more\n"
 		       "free space and try again", (long long)sb.st_size * 4);
@@ -202,8 +202,9 @@
 	    if (inPlace && Fake)
 		goto success;
=20
-	    /* Finally unpack the whole mess */
-	    if (unpack(pkg_fullname, NULL)) {
+	    /* Finally unpack the whole mess.  If extract is null we
+	       already + did so so don't bother doing it again. */
+	    if (extract && unpack(pkg_fullname, NULL)) {
 		warnx("unable to extract `%s'!", pkg_fullname);
 		goto bomb;
 	    }




On Tue, Apr 02, 2002 at 04:29:58AM -0800, murray@FreeBSD.org wrote:
> Synopsis: Adding packages with sysinstall failes after
>=20
> State-Changed-From-To: open->analyzed
> State-Changed-By: murray
> State-Changed-When: Tue Apr 2 04:29:24 PST 2002
> State-Changed-Why:=20
> David O'Brien and I spent time analyzing this.  I have a fix that I
> will commit to -CURRENT momentarily.
>=20
>=20
>=20
> Responsible-Changed-From-To: freebsd-bugs->murray
> Responsible-Changed-By: murray
> Responsible-Changed-When: Tue Apr 2 04:29:24 PST 2002
> Responsible-Changed-Why:=20
> David O'Brien and I spent time analyzing this.  I have a fix that I
> will commit to -CURRENT momentarily.
>=20
>=20
> http://www.freebsd.org/cgi/query-pr.cgi?pr=3D36606
>=20
> To Unsubscribe: send mail to majordomo@FreeBSD.org
> with "unsubscribe freebsd-bugs" in the body of the message

--EVF5PPMfhYS0aIcm
Content-Type: application/pgp-signature
Content-Disposition: inline

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.0.6 (SunOS)
Comment: For info see http://www.gnupg.org

iD8DBQE8qanLtNcQog5FH30RAu0UAKCsved/N1JyuhaXB7X8Mi8lAMlX3wCgpCZM
V/MVe0OSTUcQZdwA0aQicpM=
=HZHD
-----END PGP SIGNATURE-----

--EVF5PPMfhYS0aIcm--

To Unsubscribe: send mail to majordomo@FreeBSD.org
with "unsubscribe freebsd-bugs" in the body of the message




Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?20020402125331.GC27913>